@@ -2,7 +2,6 @@
 // Name:        wxsqlite3def.h
 // Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
 // Author:      Ulrich Telle
-// Modified by:
 // Created:     2005-07-14
 // Changes:     (see version history below, and accompanying readme file)
 //
@@ -47,9 +46,58 @@
 
 <dl>
 
+<dt><b>3.5.2</b> - <i>March 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.17.0<br>
+Fixed minor issue in SQLite encryption extension related to symbol SQLITE_DEBUG<br>
+Modified build system for GNU make (support monolithic wxWidgets build)<br>
+
+</dd>
+<dt><b>3.5.1</b> - <i>February 2017</i></dt>
+<dd>
+Added version information as Windows resource for DLL builds on Windows<br>
+Cleaned up premake5 build files for Visual C++ (corrected debug environment settings)<br>
+Resolved wxWidgets library dependencies for Visual C++ using wxWidgets' special setup.h for MSVC<br>
+
+</dd>
+<dt><b>3.5.0</b> - <i>January 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.16.2<br>
+SQLite3 library now integrated part of wxSQLite3<br>
+Build system overhauled<br>
+Added Travis Continuous Integration<br>
+
+</dd>
+<dt><b>3.4.1</b> - <i>October 2016</i></dt>
+<dd>
+Upgrade to SQLite version 3.15.0<br>
+
+</dd>
+<dt><b>3.4.0</b> - <i>August 2016</i></dt>
+<dd>
+Upgrade to SQLite version 3.14.1<br>
+Added method wxSQLite3Statement::GetExpandedSQL<br>
+Added method wxSQLite3ResultSet::GetExpandedSQL<br>
+Started to modify the build system to compile and statically link the SQLite3 library together with wxSQLite3<br>
+Added the CSV extension module as part of the SQLite3 library with encryption extension<br>
+
+</dd>
+<dt><b>3.3.1</b> - <i>April 2016</i></dt>
+<dd>
+Upgrade to SQLite version 3.12.1<br>
+Added method wxSQLite3Database::GetSystemErrorCode<br>
+
+</dd>
+<dt><b>3.3.0</b> - <i>December 2015</i></dt>
+<dd>
+Upgrade to SQLite version 3.9.2<br>
+(SQLite amalgamation source adjusted to fix problem with user authentication module)<br>
+
+</dd>
 <dt><b>3.2.1</b> - <i>March 2015</i></dt>
 <dd>
 Upgrade to SQLite version 3.8.8.3<br>
+Fixed a bug in method GetParamName<br>
 
 </dd>
 <dt><b>3.2.0</b> - <i>December 2014</i></dt>
